==> haskell-uri-bytestring-aeson-0.1.0.9-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-bytestring-aeson
version:              0.1.0.9
visibility:           public
id:                   uri-bytestring-aeson-0.1.0.9-Bjkb56odji9BqbwyqvuGSC
key:                  uri-bytestring-aeson-0.1.0.9-Bjkb56odji9BqbwyqvuGSC
license:              BSD-3-Clause
maintainer:           hafnersimon@gmail.com
author:               Simon Hafner
homepage:             https://github.com/reactormonk/uri-bytestring-aeson
synopsis:             Aeson instances for URI Bytestring
category:             URI
abi:                  f4e85d192d525062b430e80622d85cb4
exposed:              True
exposed-modules:      URI.ByteString.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring-aeson
hs-libraries:         HSuri-bytestring-aeson-0.1.0.9-Bjkb56odji9BqbwyqvuGSC
depends:
    aeson-2.1.2.1-5gViDrHjeNhDfT19MwgeMT base-4.17.2.1
    bytestring-0.11.5.3 text-2.0.2
    uri-bytestring-0.3.3.1-WX77mlqRq3HUmr5WyVLVX

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring-aeson/html/uri-bytestring-aeson.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-aeson-0.1.0.9-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-bytestring-aeson
version:              0.1.0.9
visibility:           public
id:                   uri-bytestring-aeson-0.1.0.9-HY2zhX0HVoH74e3cs8y932
key:                  uri-bytestring-aeson-0.1.0.9-HY2zhX0HVoH74e3cs8y932
license:              BSD-3-Clause
maintainer:           hafnersimon@gmail.com
author:               Simon Hafner
homepage:             https://github.com/reactormonk/uri-bytestring-aeson
synopsis:             Aeson instances for URI Bytestring
category:             URI
abi:                  ea052c7041d7042595450b21813ce917
exposed:              True
exposed-modules:      URI.ByteString.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring-aeson
hs-libraries:         HSuri-bytestring-aeson-0.1.0.9-HY2zhX0HVoH74e3cs8y932
depends:
    aeson-2.1.2.1-HdmwuFbnNgF6PqutsUaf6Y base-4.17.2.1
    bytestring-0.11.5.3 text-2.0.2
    uri-bytestring-0.3.3.1-3dW6Cs8y8X87v0gYsFsVv4

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring-aeson/html/uri-bytestring-aeson.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
